@@ -69,8 +69,8 @@ class FakeClient(object):
 
     def __init__(self, handler=None, storage=None, server_version=None):
         self._listeners = set()
-        self._child_watches = collections.defaultdict(list)
-        self._data_watches = collections.defaultdict(list)
+        self._child_watchers = collections.defaultdict(list)
+        self._data_watchers = collections.defaultdict(list)
         if handler is None:
             self._handler = k_threading.SequentialThreadingHandler()
             self._own_handler = True
@@ -122,15 +122,22 @@ class FakeClient(object):
 
     def command(self, cmd=b'ruok'):
         self.verify()
-        if cmd == 'ruok':
+        if cmd == b'ruok':
             return 'imok'
-        if cmd == 'stat':
+        if cmd == b'stat':
             server_version = ".".join([str(s) for s in self._server_version])
             return "\n".join(['Zake the fake version: %s' % (version.VERSION),
                               'Mimicked version: %s' % (server_version),
                               'Mode: standalone'])
-        if cmd == "kill":
+        if cmd == b"kill":
             self.stop()
+        if cmd == b'envi':
+            server_version = ".".join([str(s) for s in self._server_version])
+            lines = [
+                "Environment:",
+                "zookeeper.version=%s" % server_version,
+            ]
+            return "\n".join(lines)
         return ''
 
     def verify(self):
@@ -150,11 +157,11 @@ class FakeClient(object):
 
     @property
     def child_watches(self):
-        return self._child_watches
+        return self._child_watchers
 
     @property
     def data_watches(self):
-        return self._data_watches
+        return self._data_watchers
 
     @property
     def listeners(self):
@@ -215,10 +222,10 @@ class FakeClient(object):
         try:
             (data, znode) = self.storage.get(path)
         except KeyError:
-            raise k_exceptions.NoNodeError("No path %s" % (path))
+            raise k_exceptions.NoNodeError("Node %s does not exist" % (path))
         if watch:
             with self._watches_lock:
-                self._data_watches[path].append(watch)
+                self._data_watchers[path].append(watch)
         return (data, znode)
 
     def set_acls(self, path, acls, version=-1):
@@ -242,8 +249,8 @@ class FakeClient(object):
                 if not self._connected:
                     self._connected = True
                     with self._watches_lock:
-                        self._child_watches.clear()
-                        self._data_watches.clear()
+                        self._child_watchers.clear()
+                        self._data_watchers.clear()
                     self.storage.attach(self)
                     self.handler.start()
                     self._partial_client.session_id = int(uuid.uuid4())
@@ -273,7 +280,7 @@ class FakeClient(object):
             exists = None
         if watch:
             with self._watches_lock:
-                self._data_watches[path].append(watch)
+                self._data_watchers[path].append(watch)
         return exists
 
     def exists_async(self, path, watch=None):
@@ -307,7 +314,7 @@ class FakeClient(object):
             paths = self.storage.get_children(path)
         if watch:
             with self._watches_lock:
-                self._child_watches[path].append(watch)
+                self._child_watchers[path].append(watch)
         if include_data:
             children_with_data = []
             for (child_path, data) in six.iteritems(paths):
@@ -354,11 +361,11 @@ class FakeClient(object):
 
     def fire_child_watches(self, child_watches):
         for (paths, event) in child_watches:
-            self._fire_watches(paths, event, self._child_watches)
+            self._fire_watches(paths, event, self._child_watchers)
 
     def fire_data_watches(self, data_watches):
         for (paths, event) in data_watches:
-            self._fire_watches(paths, event, self._data_watches)
+            self._fire_watches(paths, event, self._data_watchers)
 
     def _fire_watches(self, paths, event, watch_source):
         for path in reversed(sorted(paths)):
@@ -393,8 +400,8 @@ class FakeClient(object):
                 if self._connected:
                     self._connected = False
                     with self._watches_lock:
-                        self._child_watches.clear()
-                        self._data_watches.clear()
+                        self._child_watchers.clear()
+                        self._data_watchers.clear()
                     self.storage.purge(self)
                     self._fire_state_change(k_states.KazooState.LOST)
                     if self._own_handler and close_handler:
