@@ -76,17 +76,24 @@ class TestClient(test.Test):
     def test_command(self):
         with start_close(self.client) as c:
             self.assertTrue(c.connected)
-            self.assertEqual("imok", c.command('ruok'))
-            self.client.command('kill')
+            self.assertEqual("imok", c.command(b'ruok'))
+            self.client.command(b'kill')
             self.assertFalse(c.connected)
 
     def test_command_version(self):
         with start_close(self.client) as c:
-            stats = c.command('stat')
+            stats = c.command(b'stat')
             self.assertIn("standalone", stats)
             version = ".".join([str(s) for s in fake_client.SERVER_VERSION])
             self.assertIn(version, stats)
 
+    def test_command_envi(self):
+        with start_close(self.client) as c:
+            envi = c.command(b'envi')
+            self.assertIn("zookeeper.version", envi)
+            version = ".".join([str(s) for s in fake_client.SERVER_VERSION])
+            self.assertIn(version, envi)
+
     def test_command_empty_version(self):
         self.assertRaises(ValueError, fake_client.FakeClient,
                           server_version=[])
@@ -94,7 +101,7 @@ class TestClient(test.Test):
     def test_command_custom_version(self):
         client = fake_client.FakeClient(server_version=(1, 1, 1))
         with start_close(client) as c:
-            stats = c.command('stat')
+            stats = c.command(b'stat')
             self.assertIn("standalone", stats)
             self.assertIn('1.1.1', stats)
 
